// MCPAPI.H -- Definitions for MCP Protocol
// Copyright (C) 2004 MagTek,Inc
// All rights reserved
#ifndef _MCPAPI_H
#define _MCPAPI_H
// The following ifdef block is the standard way of creating macros which make exporting 
// from a DLL simpler. All files within this DLL are compiled with the MCPAPI_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see 
// MCPAPI_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.
#ifdef MCPAPI_EXPORTS
#define MCPAPI_API __declspec(dllexport)
#else
#define MCPAPI_API __declspec(dllimport)
#endif

#include <windows.h>


typedef struct _MCPBUS
{
DWORD dwOperAttribute ; // operation attribute
DWORD dwApplicationID ; // application ID
DWORD dwCommandID ; // command ID
DWORD dwResultCode ; // command/notification result code
LPSTR lpszPropertyName ; // pointer to property name
DWORD dwPropertyID ; // property ID
DWORD dwPropertyType ; // property type
LPVOID lpInBuffer ; // pointer to input buffer
DWORD dwInBufferLen ; // length of data in input buffer
LPVOID lpOutBuffer ; // pointer to output buffer
DWORD dwOutBufferSize ; // output buffer size
DWORD dwResponseLen; // length of response in output buffer
DWORD dwTimeout ; // notification timeout value
DWORD dwContext ; // device enumeration context
} MCPBUS, *PMCPBUS;

//Operation Attributes
#define MCP_ATTR_NONE 0 // No attributes specified
#define MCP_ATTR_WAIT_NEW 1 // Discard any notifications that may
// have been queued before returning
// a response.
#define MCP_ATTR_PROP_DRIVER 2 // MCP Driver specific property

/* Property types */
#define MCP_TYPE_NONE 0 // No type.
#define MCP_TYPE_DWORD 1 // 32-bit unsigned integer
#define MCP_TYPE_STRING 2 // Null terminated string of 8-bit
// ANSI characters.
#define MCP_TYPE_BOOLEAN 3 // Boolean value (True=1 or False=0)
#define MCP_TYPE_BINARY 4 // Binary data
//Function Return Values
#define MCP_ST_OK 0 // successful operation
// resource manipulation
#define MCP_ST_ALLOC 20 // can't alloc (for variable size alloc/pool)
#define MCP_ST_NO_ROOM 21 // can't alloc fixed sz entry in fixed sz pool
#define MCP_ST_OVERFLOW 22 // value, buffer, whatever may overflow
#define MCP_ST_UNDERFLOW 23 // value, buffer, counter, whatever may
// underflow
#define MCP_ST_EMPTY 24 // queue/smth is empty - no elements
#define MCP_ST_FULL 25 // queue/smth is full
#define MCP_ST_EOF 26 // end of file
// valchk
#define MCP_ST_INVALID 30 // value not valid in operation context
#define MCP_ST_BAD_VALUE 31 // value not valid in module's context
#define MCP_ST_OUT_OF_RANGE 32 // value out of range
#define MCP_ST_NULL_PTR 33 // NULL ptr is not valid in operation context
#define MCP_ST_BAD_SYNTAX 34 // text/formatted data syntax error
#define MCP_ST_BAD_NAME 35 // name invalid in module's context
//Application Programmable Interface
// severe errors
#define MCP_ST_UNEXPECTED 40 // unexpected condition of parameter or
// external object
#define MCP_ST_PANIC 41 // unexpected condition of self or internal
// object
#define MCP_ST_DEADLOCK 42 // deadlock detected
#define MCP_ST_STACK_OVERFLOW 43 // stack overflow detected / no enough stack
// failures */
#define MCP_ST_REFUSE 45 // oper rejected voluntarily (inappropriate
// state)
#define MCP_ST_NO_ACTION 46 // oper requires no action (eg close closed
// file)
#define MCP_ST_FAILED 47 // operation failed / not successful
// state check
#define MCP_ST_NOT_INITED 50 // object is not initialized
#define MCP_ST_NOT_ACTIVE 51 // oper allowed only when object is active
#define MCP_ST_NOT_OPEN 52 // oper allowed only when object is open
#define MCP_ST_NOT_CONNECTED 53 // oper allowed only when object is
// connected
#define MCP_ST_NOT_CONSTRUCTED 54 // object construction not completed
// i/o system
#define MCP_ST_IOERR 60 // I/O error - file system / peripherals error
#define MCP_ST_BAD_CHKSUM 61 // wrong chksum
// set-related
#define MCP_ST_NOT_FOUND 62 // requested item not found
#define MCP_ST_DUPLICATE 63 // duplicated item is not allowed
// critical section / privileges
#define MCP_ST_BUSY 70 // in critical section (dynamic, short period)
#define MCP_ST_ACCESS_DENIED 71 // temporary lack of access (dynamic, long
// period)
#define MCP_ST_PRIVILEGE 72 // privilege violation (static)
#define MCP_ST_SCOPE_VIOLATION 73 // life, validity, etc. scope rules violated
#define MCP_ST_BAD_ACCESS 74 // access type not appropriate / not possible
// operation status
#define MCP_ST_PENDING 80 // operation is pending
#define MCP_ST_TIMEOUT 81 // timeout has expired
#define MCP_ST_CANCELED 82 // operation canceled on user's request

//MCP Driver Reference Manual
#define MCP_ST_CANCELLED MCP_ST_CANCELED
#define MCP_ST_ABORTED 83 // op. aborted on system/module's request
#define MCP_ST_RESET 84 // object has been orderly reset
#define MCP_ST_CLEANUP 85 // object is about to be destroyed, now in
// cleanup
#define MCP_ST_OVERRIDE 86 // operation/entity was overridden
#define MCP_ST_POSTPONE 87 // postpone operation: inappropriate state
// API
#define MCP_ST_CANT_BIND 90 // can't bind / resolve name, handle, etc.
#define MCP_ST_API_ERROR 91 // invalid function request, etc.
#define MCP_ST_WRONG_VERSION 92 // incompatible version of data/code detected
#define MCP_ST_NOT_IMPLEMENTED 93 // feature not implemented
#define MCP_ST_NOT_SUPPORTED 94 // feature not supported
// object model & environment
#define MCP_ST_BAD_OID 100 // invalid object id
#define MCP_ST_BAD_MESSAGE 101 // object does not handle this message


//FUNCTION PROTOTYPES

DWORD WINAPI McpEnum (MCPBUS *pMCPBUS);
DWORD WINAPI McpOpen (LPSTR lpDeviceName, HANDLE *hpDevice);
DWORD WINAPI McpClose (HANDLE hDevice);
DWORD WINAPI McpReset (HANDLE hDevice);
DWORD WINAPI McpGet (HANDLE hDevice, MCPBUS *pMCPBUS);
DWORD WINAPI McpSet (HANDLE hDevice, MCPBUS *pMCPBUS);
DWORD WINAPI McpCall (HANDLE hDevice, MCPBUS *pMCPBUS);
DWORD WINAPI McpWait (HANDLE hDevice, MCPBUS *pMCPBUS);
#endif